/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2024. All rights reserved.
 */

#ifndef DPC_IMPL_TYPE_RMRDEDGERGTGEOMETRY_H
#define DPC_IMPL_TYPE_RMRDEDGERGTGEOMETRY_H

#include <cfloat>
#include <cmath>
#include "impl_type_float.h"
#include "impl_type_boolean.h"

namespace dpc {
struct RMRdEdgeRgtgeometry {
    ::Float c0_rrdedge{ 0.0F };
    ::Float c1_rrdedge{ 0.0F };
    ::Float c2_rrdedge{ 0.0F };
    ::Float c3_rrdedge{ 0.0F };
    ::Float start_rnge_rrdedge{ 0.0F };
    ::Float end_rnge_rrdedge{ 0.0F };
    ::Float probability_rrdedge{ 0.0F };
    ::Boolean valid_rrdedge{ false };

    static bool IsPlane()
    {
        return true;
    }


    using IsEnumerableTag = void;
    template<typename F>
    void enumerate(F& fun)
    {
        fun(c0_rrdedge);
        fun(c1_rrdedge);
        fun(c2_rrdedge);
        fun(c3_rrdedge);
        fun(start_rnge_rrdedge);
        fun(end_rnge_rrdedge);
        fun(probability_rrdedge);
        fun(valid_rrdedge);
    }

    template<typename F>
    void enumerate(F& fun) const
    {
        fun(c0_rrdedge);
        fun(c1_rrdedge);
        fun(c2_rrdedge);
        fun(c3_rrdedge);
        fun(start_rnge_rrdedge);
        fun(end_rnge_rrdedge);
        fun(probability_rrdedge);
        fun(valid_rrdedge);
    }

    template<typename F>
    void enumerate_internal(F& fun)
    {
        fun("c0_rrdedge", c0_rrdedge);
        fun("c1_rrdedge", c1_rrdedge);
        fun("c2_rrdedge", c2_rrdedge);
        fun("c3_rrdedge", c3_rrdedge);
        fun("start_rnge_rrdedge", start_rnge_rrdedge);
        fun("end_rnge_rrdedge", end_rnge_rrdedge);
        fun("probability_rrdedge", probability_rrdedge);
        fun("valid_rrdedge", valid_rrdedge);
    }

    template<typename F>
    void enumerate_internal(F& fun) const
    {
        fun("c0_rrdedge", c0_rrdedge);
        fun("c1_rrdedge", c1_rrdedge);
        fun("c2_rrdedge", c2_rrdedge);
        fun("c3_rrdedge", c3_rrdedge);
        fun("start_rnge_rrdedge", start_rnge_rrdedge);
        fun("end_rnge_rrdedge", end_rnge_rrdedge);
        fun("probability_rrdedge", probability_rrdedge);
        fun("valid_rrdedge", valid_rrdedge);
    }

    friend bool operator==(const ::dpc::RMRdEdgeRgtgeometry& lhs, const ::dpc::RMRdEdgeRgtgeometry& rhs) noexcept
    {
        return (fabs(static_cast<double>(lhs.c0_rrdedge - rhs.c0_rrdedge)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.c1_rrdedge - rhs.c1_rrdedge)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.c2_rrdedge - rhs.c2_rrdedge)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.c3_rrdedge - rhs.c3_rrdedge)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.start_rnge_rrdedge - rhs.start_rnge_rrdedge)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.end_rnge_rrdedge - rhs.end_rnge_rrdedge)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.probability_rrdedge - rhs.probability_rrdedge)) < DBL_EPSILON) && (lhs.valid_rrdedge == rhs.valid_rrdedge);
    }
};
} // namespace dpc


#endif // DPC_IMPL_TYPE_RMRDEDGERGTGEOMETRY_H
